*Note: to view diagrams in this documentation, see this [README.md](https://github.com/h1st-ai/h1st/blob/api-design/docs/README.md)*

### `Model` and `Modelable`

See documentation for `Model` and `Modelable` hierarchy in [model.md](model.md)

### `Oracle` architecture

The `Oracle` architecture is a special form of __Knowledge-First AI__. See it in [oracle/oracle.py](oracle/oracle.py).

